@@ -7,6 +7,7 @@ use URI::Escape;
 use File::Spec;
 use File::Basename;
 use Pod::ProjectDocs::Template;
+use Syntax::Highlight::Universal;
 
 # most of code is borrowed from Pod::Xhtml
 __PACKAGE__->mk_accessors(qw/components local_modules current_files_output_path/);
@@ -205,6 +206,14 @@ sub _addCommand {
             my $head_level = $1;
             $anchor = $self->_addSection( "head${head_level}", $paragraph );
             $self->{buffer} .= qq(<h${head_level} id="$anchor">$paragraph</h${head_level}>\n\n);
+            (my $method = $paragraph) =~ s#^(\w+).*#$1#;
+            if ( exists $self->{_source_code}{$method} ) {
+                $self->{buffer} .= qq{<p><a href="#" onclick="toggleCode('method_$method');return false;">[Source]</a></p>
+                                        <div class="method-source-code" id="method_$method">
+                                        <pre>\n\n};
+                $self->{buffer} .= $self->{_source_code}{$method};
+                $self->{buffer} .= qq{</pre></div>\n\n};
+            }
             last;
         };
         /^item/ && do {
@@ -611,6 +620,20 @@ sub gen_html {
     my $doc        = $args{doc};
     my $components = $args{components};
     my $mgr_desc   = $args{desc};
+    my $highlighter = Syntax::Highlight::Universal->new;
+    open(FILE, $doc->origin) or warn $!;
+    while(<FILE>) {
+        next unless /^\s*sub\s+(\w+)/;
+        my $method = $1;
+        my $sub = $_;
+        while(<FILE>){
+            $sub .= $_;
+            last if /^}/;
+        }
+        my $result = $highlighter->highlight("perl", $sub);
+        $self->{_source_code}{$method} = $result;
+    }
+    close(FILE);
     $self->current_files_output_path( $doc->get_output_path );
     $self->_prepare($doc, $components, $mgr_desc);
 #   local $SIG{__WARN__} = sub { };
@@ -632,6 +655,28 @@ sub _prepare {
     $self->initialize();
     $self->addHeadText($components->{css}->tag($doc));
     $self->addHeadText(qq|<meta http-equiv="Content-Type" content="text/html; charset=$charset" />\n|);
+    $self->addHeadText(q|  <script type="text/javascript">
+
+  function toggleCode( id ) {
+    if ( document.getElementById )
+      elem = document.getElementById( id );
+    else if ( document.all )
+      elem = eval( "document.all." + id );
+    else
+      return false;
+
+    elemStyle = elem.style;
+
+    if ( elemStyle.display != "block" ) {
+      elemStyle.display = "block"
+    } else {
+      elemStyle.display = "none"
+    }
+
+    return true;
+  }
+  document.writeln( "<style type=\"text/css\">div.method-source-code { display: none }</style>" )
+  </script>|);
     $self->addBodyOpenText($self->_get_data($doc, $mgr_desc));
     $self->addBodyCloseText(
         qq|<div class="footer">generated by <a href="http://search.cpan.org/perldoc?|
